button

Function button 

pub fn button() -> ButtonElement
The HTML <button> element represents a clickable button, used to submit forms or anywhere in a document for accessible, standard button functionality.