pub fn col() -> ColElementExpand description
The HTML <col> element defines a column within a table and is used for defining common semantics on all common cells. It is generally found within a colgroup element.
pub fn col() -> ColElementThe HTML <col> element defines a column within a table and is used for defining common semantics on all common cells. It is generally found within a colgroup element.