pub struct TrElement(/* private fields */);Expand description
The HTML <tr> element defines a row of cells in a table. The row’s cells can then be established using a mix of td (data cell) and th (header cell) elements.
Implementations
Sourceimpl TrElement
impl TrElement
pub fn new() -> Self
pub fn future<F>(self, f: impl FnOnce(&Element) -> F) -> Self
pub fn attribute<T>(self, name: impl Into<Cow<'static, str>>, value: T) -> Selfwhere
T: IntoAttributeValue,
pub fn attribute_signal<T, S>( self, name: impl Into<Cow<'static, str>>, value: S, ) -> Self
pub fn class<T>(self, value: T) -> Selfwhere
T: IntoOptionStringValue,
pub fn class_signal<S, T>(self, value: S) -> Self
pub fn style<T>(self, name: impl Into<Cow<'static, str>>, value: T) -> Selfwhere
T: IntoOptionStringValue,
pub fn style_signal<S, T>( self, name: impl Into<Cow<'static, str>>, value: S, ) -> Self
pub fn event( self, name: impl Into<Cow<'static, str>>, closure: impl 'static + FnMut(JsValue), ) -> Self
pub fn child<T>(self, child: T) -> Self
pub fn children<T, I>(self, children: I) -> Self
pub fn child_signal<T, S>(self, signal: S) -> Self
pub fn child_signal_vec<T, S>(self, signal_vec: S) -> Self
pub fn inner_html(self, value: impl IntoStringValue) -> Self
Sourceimpl TrElement
impl TrElement
Sourcepub fn accesskey<T>(self, value: T) -> Selfwhere
T: IntoAttributeValue,
pub fn accesskey<T>(self, value: T) -> Selfwhere
T: IntoAttributeValue,
Provides a hint for generating a keyboard shortcut for the current element. This attribute consists of a space-separated list of characters. The browser should use the first one that exists on the computer keyboard layout.
pub fn accesskey_signal<T, S>(self, value: S) -> Self
Sourcepub fn autocapitalize<T>(self, value: T) -> Selfwhere
T: IntoAttributeValue,
pub fn autocapitalize<T>(self, value: T) -> Selfwhere
T: IntoAttributeValue,
Controls whether and how text input is automatically capitalized as it is entered/edited by the user. It can have the following values: * off or none, no autocapitalization is applied (all letters default to lowercase) * on or sentences, the first letter of each sentence defaults to a capital letter; all other letters default to lowercase * words, the first letter of each word defaults to a capital letter; all other letters default to lowercase * characters, all letters should default to uppercase
pub fn autocapitalize_signal<T, S>(self, value: S) -> Self
Sourcepub fn contenteditable<T>(self, value: T) -> Selfwhere
T: IntoAttributeValue,
pub fn contenteditable<T>(self, value: T) -> Selfwhere
T: IntoAttributeValue,
A space-separated list of the classes of the element. Classes allows CSS and JavaScript to select and access specific elements via the class selectors or functions like the method Document.getElementsByClassName().
An enumerated attribute indicating if the element should be editable by the user. If so, the browser modifies its widget to allow editing. The attribute must take one of the following values:
true or the empty string, which indicates that the element must be editable;
false, which indicates that the element must not be editable.
pub fn contenteditable_signal<T, S>(self, value: S) -> Self
The id of a <menu> to use as the contextual menu for this element.
Sourcepub fn dir<T>(self, value: T) -> Selfwhere
T: IntoAttributeValue,
pub fn dir<T>(self, value: T) -> Selfwhere
T: IntoAttributeValue,
An enumerated attribute indicating the directionality of the element’s text. It can have the following values: * ltr, which means left to right and is to be used for languages that are written from the left to the right (like English); * rtl, which means right to left and is to be used for languages that are written from the right to the left (like Arabic); * auto, which lets the user agent decide. It uses a basic algorithm as it parses the characters inside the element until it finds a character with a strong directionality, then it applies that directionality to the whole element.
pub fn dir_signal<T, S>(self, value: S) -> Self
Sourcepub fn draggable<T>(self, value: T) -> Selfwhere
T: IntoAttributeValue,
pub fn draggable<T>(self, value: T) -> Selfwhere
T: IntoAttributeValue,
An enumerated attribute indicating whether the element can be dragged, using the Drag and Drop API. It can have the following values: * true, which indicates that the element may be dragged * false, which indicates that the element may not be dragged.
pub fn draggable_signal<T, S>(self, value: S) -> Self
Sourcepub fn enterkeyhint<T>(self, value: T) -> Selfwhere
T: IntoAttributeValue,
pub fn enterkeyhint<T>(self, value: T) -> Selfwhere
T: IntoAttributeValue,
Hints what action label (or icon) to present for the enter key on virtual keyboards.
pub fn enterkeyhint_signal<T, S>(self, value: S) -> Self
Sourcepub fn exportparts<T>(self, value: T) -> Selfwhere
T: IntoAttributeValue,
pub fn exportparts<T>(self, value: T) -> Selfwhere
T: IntoAttributeValue,
Used to transitively export shadow parts from a nested shadow tree into a containing light tree.
pub fn exportparts_signal<T, S>(self, value: S) -> Self
A Boolean attribute indicates that the element is not yet, or is no longer, relevant. For example, it can be used to hide elements of the page that can’t be used until the login process has been completed. The browser won’t render such elements. This attribute must not be used to hide content that could legitimately be shown.
Sourcepub fn id<T>(self, value: T) -> Selfwhere
T: IntoAttributeValue,
pub fn id<T>(self, value: T) -> Selfwhere
T: IntoAttributeValue,
Defines a unique identifier (ID) which must be unique in the whole document. Its purpose is to identify the element when linking (using a fragment identifier), scripting, or styling (with CSS).
pub fn id_signal<T, S>(self, value: S) -> Self
Sourcepub fn inputmode<T>(self, value: T) -> Selfwhere
T: IntoAttributeValue,
pub fn inputmode<T>(self, value: T) -> Selfwhere
T: IntoAttributeValue,
Provides a hint to browsers as to the type of virtual keyboard configuration to use when editing this element or its contents. Used primarily on <input> elements, but is usable on any element while in contenteditable mode.
pub fn inputmode_signal<T, S>(self, value: S) -> Self
Sourcepub fn is<T>(self, value: T) -> Selfwhere
T: IntoAttributeValue,
pub fn is<T>(self, value: T) -> Selfwhere
T: IntoAttributeValue,
Allows you to specify that a standard HTML element should behave like a registered custom built-in element (see Using custom elements for more details).
pub fn is_signal<T, S>(self, value: S) -> Self
Sourcepub fn itemid<T>(self, value: T) -> Selfwhere
T: IntoAttributeValue,
pub fn itemid<T>(self, value: T) -> Selfwhere
T: IntoAttributeValue,
The unique, global identifier of an item.
pub fn itemid_signal<T, S>(self, value: S) -> Self
Sourcepub fn itemprop<T>(self, value: T) -> Selfwhere
T: IntoAttributeValue,
pub fn itemprop<T>(self, value: T) -> Selfwhere
T: IntoAttributeValue,
Used to add properties to an item. Every HTML element may have an itemprop attribute specified, where an itemprop consists of a name and value pair.
pub fn itemprop_signal<T, S>(self, value: S) -> Self
Sourcepub fn itemref<T>(self, value: T) -> Selfwhere
T: IntoAttributeValue,
pub fn itemref<T>(self, value: T) -> Selfwhere
T: IntoAttributeValue,
Properties that are not descendants of an element with the itemscope attribute can be associated with the item using an itemref. It provides a list of element ids (not itemids) with additional properties elsewhere in the document.
pub fn itemref_signal<T, S>(self, value: S) -> Self
Sourcepub fn itemscope<T>(self, value: T) -> Selfwhere
T: IntoAttributeValue,
pub fn itemscope<T>(self, value: T) -> Selfwhere
T: IntoAttributeValue,
itemscope (usually) works along with itemtype to specify that the HTML contained in a block is about a particular item. itemscope creates the Item and defines the scope of the itemtype associated with it. itemtype is a valid URL of a vocabulary (such as schema.org) that describes the item and its properties context.
pub fn itemscope_signal<T, S>(self, value: S) -> Self
Sourcepub fn itemtype<T>(self, value: T) -> Selfwhere
T: IntoAttributeValue,
pub fn itemtype<T>(self, value: T) -> Selfwhere
T: IntoAttributeValue,
Specifies the URL of the vocabulary that will be used to define itemprops (item properties) in the data structure. itemscope is used to set the scope of where in the data structure the vocabulary set by itemtype will be active.
pub fn itemtype_signal<T, S>(self, value: S) -> Self
Sourcepub fn lang<T>(self, value: T) -> Selfwhere
T: IntoAttributeValue,
pub fn lang<T>(self, value: T) -> Selfwhere
T: IntoAttributeValue,
Helps define the language of an element: the language that non-editable elements are in, or the language that editable elements should be written in by the user. The attribute contains one \u201clanguage tag\u201d (made of hyphen-separated \u201clanguage subtags\u201d) in the format defined in Tags for Identifying Languages (BCP47). xml:lang has priority over it.
pub fn lang_signal<T, S>(self, value: S) -> Self
Sourcepub fn nonce<T>(self, value: T) -> Selfwhere
T: IntoAttributeValue,
pub fn nonce<T>(self, value: T) -> Selfwhere
T: IntoAttributeValue,
A cryptographic nonce (“number used once”) which can be used by Content Security Policy to determine whether or not a given fetch will be allowed to proceed.
pub fn nonce_signal<T, S>(self, value: S) -> Self
Sourcepub fn part<T>(self, value: T) -> Selfwhere
T: IntoAttributeValue,
pub fn part<T>(self, value: T) -> Selfwhere
T: IntoAttributeValue,
A space-separated list of the part names of the element. Part names allows CSS to select and style specific elements in a shadow tree via the ::part pseudo-element.
pub fn part_signal<T, S>(self, value: S) -> Self
Sourcepub fn slot<T>(self, value: T) -> Selfwhere
T: IntoAttributeValue,
pub fn slot<T>(self, value: T) -> Selfwhere
T: IntoAttributeValue,
Assigns a slot in a shadow DOM shadow tree to an element: An element with a slot attribute is assigned to the slot created by the <slot> element whose name attribute’s value matches that slot attribute’s value.
pub fn slot_signal<T, S>(self, value: S) -> Self
Sourcepub fn spellcheck<T>(self, value: T) -> Selfwhere
T: IntoAttributeValue,
pub fn spellcheck<T>(self, value: T) -> Selfwhere
T: IntoAttributeValue,
An enumerated attribute defines whether the element may be checked for spelling errors. It may have the following values: * true, which indicates that the element should be, if possible, checked for spelling errors; * false, which indicates that the element should not be checked for spelling errors.
pub fn spellcheck_signal<T, S>(self, value: S) -> Self
Sourcepub fn tabindex<T>(self, value: T) -> Selfwhere
T: IntoAttributeValue,
pub fn tabindex<T>(self, value: T) -> Selfwhere
T: IntoAttributeValue,
An integer attribute indicating if the element can take input focus (is focusable), if it should participate to sequential keyboard navigation, and if so, at what position. It can take several values: * a negative value means that the element should be focusable, but should not be reachable via sequential keyboard navigation; * 0 means that the element should be focusable and reachable via sequential keyboard navigation, but its relative order is defined by the platform convention; * a positive value means that the element should be focusable and reachable via sequential keyboard navigation; the order in which the elements are focused is the increasing value of the tabindex. If several elements share the same tabindex, their relative order follows their relative positions in the document.
pub fn tabindex_signal<T, S>(self, value: S) -> Self
Sourcepub fn title<T>(self, value: T) -> Selfwhere
T: IntoAttributeValue,
pub fn title<T>(self, value: T) -> Selfwhere
T: IntoAttributeValue,
Contains a text representing advisory information related to the element it belongs to. Such information can typically, but not necessarily, be presented to the user as a tooltip.
pub fn title_signal<T, S>(self, value: S) -> Self
Sourcepub fn translate<T>(self, value: T) -> Selfwhere
T: IntoAttributeValue,
pub fn translate<T>(self, value: T) -> Selfwhere
T: IntoAttributeValue,
An enumerated attribute that is used to specify whether an element’s attribute values and the values of its Text node children are to be translated when the page is localized, or whether to leave them unchanged. It can have the following values: * empty string and yes, which indicates that the element will be translated. * no, which indicates that the element will not be translated.
pub fn translate_signal<T, S>(self, value: S) -> Self
Sourceimpl TrElement
impl TrElement
Sourcepub fn onerror(self, closure: impl 'static + FnMut(Event)) -> Self
pub fn onerror(self, closure: impl 'static + FnMut(Event)) -> Self
Fired when a resource failed to load, or can’t be used. For example, if a script has an execution error or an image can’t be found or is invalid.
Sourcepub fn onscroll(self, closure: impl 'static + FnMut(Event)) -> Self
pub fn onscroll(self, closure: impl 'static + FnMut(Event)) -> Self
Fired when the document view or an element has been scrolled.
Sourcepub fn onselect(self, closure: impl 'static + FnMut(Event)) -> Self
pub fn onselect(self, closure: impl 'static + FnMut(Event)) -> Self
Fired when some text has been selected.
Sourcepub fn onshow(self, closure: impl 'static + FnMut(Event)) -> Self
pub fn onshow(self, closure: impl 'static + FnMut(Event)) -> Self
Fired when a contextmenu event was fired on/bubbled to an element that has a contextmenu attribute.
Sourcepub fn onwheel(self, closure: impl 'static + FnMut(Event)) -> Self
pub fn onwheel(self, closure: impl 'static + FnMut(Event)) -> Self
Fired when the user rotates a wheel button on a pointing device (typically a mouse).
Sourcepub fn oncopy(self, closure: impl 'static + FnMut(Event)) -> Self
pub fn oncopy(self, closure: impl 'static + FnMut(Event)) -> Self
Fired when the user initiates a copy action through the browser’s user interface.
Sourcepub fn oncut(self, closure: impl 'static + FnMut(Event)) -> Self
pub fn oncut(self, closure: impl 'static + FnMut(Event)) -> Self
Fired when the user initiates a cut action through the browser’s user interface.
Sourcepub fn onpaste(self, closure: impl 'static + FnMut(Event)) -> Self
pub fn onpaste(self, closure: impl 'static + FnMut(Event)) -> Self
Fired when the user initiates a paste action through the browser’s user interface.
Sourcepub fn oncompositionend(
self,
closure: impl 'static + FnMut(CompositionEvent),
) -> Self
pub fn oncompositionend( self, closure: impl 'static + FnMut(CompositionEvent), ) -> Self
Fired when a text composition system such as an input method editor completes or cancels the current composition session.
Sourcepub fn oncompositionstart(
self,
closure: impl 'static + FnMut(CompositionEvent),
) -> Self
pub fn oncompositionstart( self, closure: impl 'static + FnMut(CompositionEvent), ) -> Self
Fired when a text composition system such as an input method editor starts a new composition session.
Sourcepub fn oncompositionupdate(
self,
closure: impl 'static + FnMut(CompositionEvent),
) -> Self
pub fn oncompositionupdate( self, closure: impl 'static + FnMut(CompositionEvent), ) -> Self
Fired when a new character is received in the context of a text composition session controlled by a text composition system such as an input method editor.
Sourcepub fn onblur(self, closure: impl 'static + FnMut(FocusEvent)) -> Self
pub fn onblur(self, closure: impl 'static + FnMut(FocusEvent)) -> Self
Fired when an element has lost focus.
Sourcepub fn onfocus(self, closure: impl 'static + FnMut(FocusEvent)) -> Self
pub fn onfocus(self, closure: impl 'static + FnMut(FocusEvent)) -> Self
Fired when an element has gained focus.
Sourcepub fn onfocusin(self, closure: impl 'static + FnMut(FocusEvent)) -> Self
pub fn onfocusin(self, closure: impl 'static + FnMut(FocusEvent)) -> Self
Fired when an element is about to gain focus.
Sourcepub fn onfocusout(self, closure: impl 'static + FnMut(FocusEvent)) -> Self
pub fn onfocusout(self, closure: impl 'static + FnMut(FocusEvent)) -> Self
Fired when an element is about to lose focus.
Sourcepub fn onfullscreenchange(self, closure: impl 'static + FnMut(Event)) -> Self
pub fn onfullscreenchange(self, closure: impl 'static + FnMut(Event)) -> Self
Sent to an Element when it transitions into or out of full-screen mode.
Sourcepub fn onfullscreenerror(self, closure: impl 'static + FnMut(Event)) -> Self
pub fn onfullscreenerror(self, closure: impl 'static + FnMut(Event)) -> Self
Sent to an Element if an error occurs while attempting to switch it into or out of full-screen mode.
Sourcepub fn onkeydown(self, closure: impl 'static + FnMut(KeyboardEvent)) -> Self
pub fn onkeydown(self, closure: impl 'static + FnMut(KeyboardEvent)) -> Self
Fired when a key is pressed.
Sourcepub fn onkeypress(self, closure: impl 'static + FnMut(KeyboardEvent)) -> Self
pub fn onkeypress(self, closure: impl 'static + FnMut(KeyboardEvent)) -> Self
Fired when a key that produces a character value is pressed down.
Sourcepub fn onkeyup(self, closure: impl 'static + FnMut(KeyboardEvent)) -> Self
pub fn onkeyup(self, closure: impl 'static + FnMut(KeyboardEvent)) -> Self
Fired when a key is released.
Sourcepub fn onauxclick(self, closure: impl 'static + FnMut(MouseEvent)) -> Self
pub fn onauxclick(self, closure: impl 'static + FnMut(MouseEvent)) -> Self
Fired when a non-primary pointing device button (e.g., any mouse button other than the left button) has been pressed and released on an element.
Sourcepub fn onclick(self, closure: impl 'static + FnMut(MouseEvent)) -> Self
pub fn onclick(self, closure: impl 'static + FnMut(MouseEvent)) -> Self
Fired when a pointing device button (e.g., a mouse’s primary button) is pressed and released on a single element.
Fired when the user attempts to open a context menu.
Sourcepub fn ondblclick(self, closure: impl 'static + FnMut(MouseEvent)) -> Self
pub fn ondblclick(self, closure: impl 'static + FnMut(MouseEvent)) -> Self
Fired when a pointing device button (e.g., a mouse’s primary button) is clicked twice on a single element.
Sourcepub fn onDOMActivate(self, closure: impl 'static + FnMut(MouseEvent)) -> Self
pub fn onDOMActivate(self, closure: impl 'static + FnMut(MouseEvent)) -> Self
Occurs when an element is activated, for instance, through a mouse click or a keypress.
Sourcepub fn onmousedown(self, closure: impl 'static + FnMut(MouseEvent)) -> Self
pub fn onmousedown(self, closure: impl 'static + FnMut(MouseEvent)) -> Self
Fired when a pointing device button is pressed on an element.
Sourcepub fn onmouseenter(self, closure: impl 'static + FnMut(MouseEvent)) -> Self
pub fn onmouseenter(self, closure: impl 'static + FnMut(MouseEvent)) -> Self
Fired when a pointing device (usually a mouse) is moved over the element that has the listener attached.
Sourcepub fn onmouseleave(self, closure: impl 'static + FnMut(MouseEvent)) -> Self
pub fn onmouseleave(self, closure: impl 'static + FnMut(MouseEvent)) -> Self
Fired when the pointer of a pointing device (usually a mouse) is moved out of an element that has the listener attached to it.
Sourcepub fn onmousemove(self, closure: impl 'static + FnMut(MouseEvent)) -> Self
pub fn onmousemove(self, closure: impl 'static + FnMut(MouseEvent)) -> Self
Fired when a pointing device (usually a mouse) is moved while over an element.
Sourcepub fn onmouseout(self, closure: impl 'static + FnMut(MouseEvent)) -> Self
pub fn onmouseout(self, closure: impl 'static + FnMut(MouseEvent)) -> Self
Fired when a pointing device (usually a mouse) is moved off the element to which the listener is attached or off one of its children.
Sourcepub fn onmouseover(self, closure: impl 'static + FnMut(MouseEvent)) -> Self
pub fn onmouseover(self, closure: impl 'static + FnMut(MouseEvent)) -> Self
Fired when a pointing device is moved onto the element to which the listener is attached or onto one of its children.
Sourcepub fn onmouseup(self, closure: impl 'static + FnMut(MouseEvent)) -> Self
pub fn onmouseup(self, closure: impl 'static + FnMut(MouseEvent)) -> Self
Fired when a pointing device button is released on an element.
Sourcepub fn onwebkitmouseforcechanged(
self,
closure: impl 'static + FnMut(MouseEvent),
) -> Self
pub fn onwebkitmouseforcechanged( self, closure: impl 'static + FnMut(MouseEvent), ) -> Self
Fired each time the amount of pressure changes on the trackpadtouchscreen.
Sourcepub fn onwebkitmouseforcedown(
self,
closure: impl 'static + FnMut(MouseEvent),
) -> Self
pub fn onwebkitmouseforcedown( self, closure: impl 'static + FnMut(MouseEvent), ) -> Self
Fired after the mousedown event as soon as sufficient pressure has been applied to qualify as a “force click”.
Sourcepub fn onwebkitmouseforcewillbegin(
self,
closure: impl 'static + FnMut(MouseEvent),
) -> Self
pub fn onwebkitmouseforcewillbegin( self, closure: impl 'static + FnMut(MouseEvent), ) -> Self
Fired before the mousedown event.
Sourcepub fn onwebkitmouseforceup(
self,
closure: impl 'static + FnMut(MouseEvent),
) -> Self
pub fn onwebkitmouseforceup( self, closure: impl 'static + FnMut(MouseEvent), ) -> Self
Fired after the webkitmouseforcedown event as soon as the pressure has been reduced sufficiently to end the “force click”.
Sourcepub fn ontouchcancel(self, closure: impl 'static + FnMut(TouchEvent)) -> Self
pub fn ontouchcancel(self, closure: impl 'static + FnMut(TouchEvent)) -> Self
Fired when one or more touch points have been disrupted in an implementation-specific manner (for example, too many touch points are created).
Sourcepub fn ontouchend(self, closure: impl 'static + FnMut(TouchEvent)) -> Self
pub fn ontouchend(self, closure: impl 'static + FnMut(TouchEvent)) -> Self
Fired when one or more touch points are removed from the touch surface.
Sourcepub fn ontouchmove(self, closure: impl 'static + FnMut(TouchEvent)) -> Self
pub fn ontouchmove(self, closure: impl 'static + FnMut(TouchEvent)) -> Self
Fired when one or more touch points are moved along the touch surface.
Sourcepub fn ontouchstart(self, closure: impl 'static + FnMut(TouchEvent)) -> Self
pub fn ontouchstart(self, closure: impl 'static + FnMut(TouchEvent)) -> Self
Fired when one or more touch points are placed on the touch surface.