pub fn button() -> ButtonElementExpand description
The HTML <button> element represents a clickable button, used to submit forms or anywhere in a document for accessible, standard button functionality.
pub fn button() -> ButtonElementThe HTML <button> element represents a clickable button, used to submit forms or anywhere in a document for accessible, standard button functionality.